/***************************************************************************
;
;    This module is presented here only to serve as a sample for
;    8051 program development on the MINI-MAX/51-F system.
;    BiPOM Electronics does not guarantee its functionality
;    with other micro-controller systems.
;    Please e-mail any questions and suggestions to tech@bipom.com
;
;    Module: ADC.C
;
;    Revision: 1.01
;
;    Description:	Demonstrates the Analog To Digital Converter (ADC) 
;					on the MINI-MAX/51-F board.   
;
;    This program is written using Micro-C Compiler from
;    Dunfield Development Systems.
;
*****************************************************************************/
#include <8051io.h>
#include <8051bit.h>            /* Bit set/clear macros */
#include <8051reg.h>
#include "MSC1211.h"

/* DEFINES */
#define UBYTE	unsigned char
#define VREF 2.5
#define GND 0.0
#define FULL_SCALE 16777215.0
//
struct DW {UBYTE data[4];};
// function declarations
void	unipolar	(register struct DW DoubleWord);
void	calibrate	(void);
//
register int decimation;
//
main()
{
	register struct DW adc_result;
	decimation = 1920;
    /* Set the serial port to 9600 Baud */
    serinit(9600);
	calibrate();
    for (;;)
    {
    	while (!(AIE & 0x20));
       	unipolar(adc_result);
    	printf("\n %02x%02x%02xh",
    		adc_result.data[2],
    		adc_result.data[1],adc_result.data[0]);
    	
  //  	delay(500);	
    }
}
//
void unipolar ( register struct DW DoubleWord )
{
	DoubleWord.data[3] = 0;
	DoubleWord.data[2] = ADRESH;
	DoubleWord.data[1] = ADRESM;
	DoubleWord.data[0] = ADRESL;
}
//
void calibrate ( void ) 
{
	UBYTE i;
	register struct DW DoubleWord;
	printf ("\n\nUnipolar mode (AIN0)\n");

	// Timer Setup 
	PASEL = 0xFF;
	USEC   = 21; 			// 22 MHz Clock
	ACLK   = 17; 			// ACLK = 22,1184,000 / 18 = 1.2288MHz
										// modclock = 1.2288MHz / 64 = 19,200 Hz

	// Setup ADC 					
	PDCON &= 0xF7;		// turn on ADC
	ADMUX = 0x08;		// Select Analog Channel 0

	
	// VRefOn, VRef Hi, Burnout Detect Off, PGA = 1
	ADCON0 = 0x30;		 								

	// unipolar auto, self calibration, offset, gain
	ADCON1 = 0x41;

	
	//Note that if decimation is too low, noise will appear...
	ADCON2 = decimation & 0xFF;			// LSB of decimation	
	ADCON3 = (decimation>>8) & 0x07;	// MSB of decimation	
	
	printf ( "Calibrating. . .\n");
	
	for ( i = 0; i<4; i++ ) {
		
		// Wait for four conversions for filter to settle after calibration
		while (!(AIE & 0x20));
		
		// dummy read to clear ADCIRQ
		unipolar(DoubleWord); 	
	}
}
/*EOF*/
